( cd usr/bin ; rm -rf awk )
( cd usr/bin ; ln -sf gawk awk )
( cd usr/bin ; rm -rf bash )
( cd usr/bin ; ln -sf /bin/bash bash )
( cd usr/bin ; rm -rf vi )
( cd usr/bin ; ln -sf elvis vi )
( cd usr/bin ; rm -rf view )
( cd usr/bin ; ln -sf elvis view )
( cd usr/bin ; rm -rf install )
( cd usr/bin ; ln -sf ginstall install )
( cd usr/bin ; rm -rf uncompress )
( cd usr/bin ; ln -sf compress uncompress )
( cd usr/bin ; rm -rf batch )
( cd usr/bin ; ln -sf at batch )
( cd usr/bin ; rm -rf atq )
( cd usr/bin ; ln -sf at atq )
( cd usr/bin ; rm -rf atrm )
( cd usr/bin ; ln -sf at atrm )
( cd usr/bin ; rm -rf input )
( cd usr/bin ; ln -sf elvis input )
( cd usr/bin ; rm -rf ex )
( cd usr/bin ; ln -sf elvis ex )
( cd usr/bin ; rm -rf manpath )
( cd usr/bin ; ln -sf man manpath )
( cd usr/lib ; rm -rf makewhatis )
( cd usr/lib ; ln -sf /usr/sbin/makewhatis makewhatis )
( cd sbin ; rm -rf depmod )
( cd sbin ; ln -sf modprobe depmod )
( cd sbin ; rm -rf fsck.hpfs )
( cd sbin ; ln -sf /bin/true fsck.hpfs )
( cd sbin ; rm -rf fsck.msdos )
( cd sbin ; ln -sf /bin/true fsck.msdos )
( cd sbin ; rm -rf fsck.umsdos )
( cd sbin ; ln -sf /bin/true fsck.umsdos )
( cd sbin ; rm -rf fsck.xiafs )
( cd sbin ; ln -sf xfsck fsck.xiafs )
( cd sbin ; rm -rf mkfs.msdos )
( cd sbin ; ln -sf mkdosfs mkfs.msdos )
( cd sbin ; rm -rf mkfs.xiafs )
( cd sbin ; ln -sf mkxfs mkfs.xiafs )
( cd bin ; rm -rf red )
( cd bin ; ln -sf ed red )
( cd bin ; rm -rf compress )
( cd bin ; ln -sf /usr/bin/compress compress )
